@@ -1,9 +1,10 @@
 #-----------------------------------------------------------------------
-# $Id: wrappers.py 2352 2013-03-15 09:38:10Z meissls $
+# $Id$
 #
 # Project: EOxServer <http://eoxserver.org>
 # Authors: Stephan Krause <stephan.krause@eox.at>
 #          Stephan Meissl <stephan.meissl@eox.at>
+#          Martin Paces <martin.paces@eox.at>
 #
 #-------------------------------------------------------------------------------
 # Copyright (C) 2011 EOX IT Services GmbH
@@ -36,10 +37,10 @@ with additional application logic.
 
 import os.path
 import operator
+import logging
 
-from django.db.models import Min, Max
 from django.contrib.gis.geos import GEOSGeometry
-from django.contrib.gis.geos.geometry import MultiPolygon
+from django.contrib.gis.geos.geometry import MultiPolygon, Polygon
 from django.contrib.gis.db.models import Union
 
 from eoxserver.core.system import System
@@ -63,6 +64,9 @@ from eoxserver.resources.coverages.rangetype import (
     Band, NilValue, RangeType
 )
 
+
+logger = logging.getLogger(__name__)
+
 #-----------------------------------------------------------------------
 # Wrapper implementations
 #-----------------------------------------------------------------------
@@ -81,6 +85,15 @@ class CoverageWrapper(ResourceWrapper):
     @property
     def __model(self):
         return self._ResourceWrapper__model
+
+
+    def isAutomatic(self): 
+        """
+        Returns ``True`` if the coverage is automatic or ``False`` otherwise. 
+        """
+        
+        return self.__model.automatic
+
     
     def getCoverageId(self):
         """
@@ -268,22 +281,22 @@ class CoverageWrapper(ResourceWrapper):
         if data_source:
             pass # TODO
         
-
-class RectifiedGridWrapper(object):
+class CommonGridWrapper(object): 
     """
-    This wrapper is intended as a mix-in for coverages that rely on a
-    rectified grid. It implements :class:`~.RectifiedGridInterface`.
-    """    
+    Common base class shared by :class:`~.RectifiedGridWrapper`
+    and :class:`~.ReferenceableGridWrapper`
+   """
+
     @property
     def __model(self):
         return self._ResourceWrapper__model
-        
+
     def _get_create_dict(self, params):
-        create_dict = super(RectifiedGridWrapper, self)._get_create_dict(params)
+        create_dict = super(CommonGridWrapper, self)._get_create_dict(params)
         
         if "geo_metadata" not in params:
             raise InternalError(
-                "Missing mandatory 'coverage_id' parameter for RectifiedDataset creation."
+                "Missing mandatory 'coverage_id' parameter for dataset creation."
             )
         
         geo_metadata = params["geo_metadata"]
@@ -301,7 +314,7 @@ class RectifiedGridWrapper(object):
         return create_dict
 
     def _updateModel(self, link_kwargs, unlink_kwargs, set_kwargs):
-        super(RectifiedGridWrapper, self)._updateModel(link_kwargs, unlink_kwargs, set_kwargs)
+        super(CommonGridWrapper, self)._updateModel(link_kwargs, unlink_kwargs, set_kwargs)
         
         geo_md = set_kwargs.get("geo_metadata")
         if geo_md:
@@ -336,7 +349,13 @@ class RectifiedGridWrapper(object):
             self.__model.extent.maxx,
             self.__model.extent.maxy
         )
-        
+
+class RectifiedGridWrapper(CommonGridWrapper):
+    """
+    This wrapper is intended as a mix-in for coverages that rely on a
+    rectified grid. It implements :class:`~.RectifiedGridInterface`.
+    """    
+
     def getResolution(self):
         """
         Returns the coverage resolution as a 2-tuple of float values for the 
@@ -350,28 +369,13 @@ class RectifiedGridWrapper(object):
             (extent[3] - extent[1]) / float(size[1])
         )
 
-class ReferenceableGridWrapper(object):
+class ReferenceableGridWrapper(CommonGridWrapper):
     """
     This wrapper is intended as a mix-in for coverages that rely on
-    referenceable grids. It has yet to be implemented.
-    
-    .. note:: The design for referenceable grids is yet TBD.
+    referenceable grids. It implements :class:`~.ReferenceableGridInterface`.
     """
+    pass 
     
-    def _get_create_dict(self, params):
-        create_dict = super(ReferenceableGridWrapper, self)._get_create_dict(params)
-        
-        if "geo_metadata" not in params:
-            raise InternalError(
-                "Missing mandatory 'coverage_id' parameter for RectifiedDataset creation."
-            )
-        
-        geo_metadata = params["geo_metadata"]
-        
-        create_dict["size_x"] = geo_metadata.size_x
-        create_dict["size_y"] = geo_metadata.size_y
-
-        return create_dict
 
 class PackagedDataWrapper(object):
     """
@@ -885,10 +889,18 @@ class ReferenceableDatasetWrapper(ReferenceableGridWrapper, EODatasetWrapper):
         * ``filename``: the path to the dataset; value must be a string
         * ``metadata_filename``: the path to the accompanying metadata
           file; value must be a string
+        * ``srid``: the SRID of the dataset's CRS; value must be an integer
         * ``size_x``: the width of the coverage in pixels; value must be
           an integer
         * ``size_y``: the height of the coverage in pixels; value must be
           an integer
+        * ``minx``: the left hand bound of the dataset's extent; value must
+          be numeric
+        * ``miny``: the lower bound of the dataset's extent; value must be
+          numeric
+        * ``maxx``: the right hand bound of the dataset's extent; value must
+          be numeric
+        * ``maxy``: the upper bound of the dataset's extent; value must be
         * ``visible``: the ``visible`` attribute of the dataset; value must
           be boolean
         * ``automatic``: the ``automatic`` attribute of the dataset; value
@@ -908,8 +920,13 @@ class ReferenceableDatasetWrapper(ReferenceableGridWrapper, EODatasetWrapper):
     FIELDS = {
         "eo_id": "eo_id",
         "data_package": "data_package",
-        "size_x": "size_x",
-        "size_y": "size_y",
+        "srid": "extent__srid",
+        "size_x": "extent__size_x",
+        "size_y": "extent__size_y",
+        "minx": "extent__minx",
+        "miny": "extent__miny",
+        "maxx": "extent__maxx",
+        "maxy": "extent__maxy",
         "visible": "visible",
         "automatic": "automatic",
         "begin_time": "eo_metadata__timestamp_begin",
@@ -967,7 +984,7 @@ class ReferenceableDatasetWrapper(ReferenceableGridWrapper, EODatasetWrapper):
         ``(size_x, size_y)``.
         """
         
-        return (self.__model.size_x, self.__model.size_y)
+        return (self.__model.extent.size_x, self.__model.extent.size_y)
 
     #-------------------------------------------------------------------
     #  EOCoverageInterface implementations
@@ -1158,8 +1175,14 @@ class RectifiedStitchedMosaicWrapper(TiledDataWrapper, RectifiedGridWrapper, EOC
                 rectifieddatasetrecord_set__in = qs
             )
             
-            begin_time = min(eo_metadata_set.values_list('timestamp_begin', flat=True))
-            end_time = max(eo_metadata_set.values_list('timestamp_end', flat=True))
+            try:
+                begin_time = min(eo_metadata_set.values_list('timestamp_begin', flat=True))
+                end_time = max(eo_metadata_set.values_list('timestamp_end', flat=True))
+            # Work around for issue in Django 1.5
+            except TypeError:
+                begin_time = min([t.timestamp_begin for t in eo_metadata_set])
+                end_time = max([t.timestamp_end for t in eo_metadata_set])
+            
             footprint = eo_metadata_set.aggregate(
                 Union('footprint')
             )["footprint__union"]
@@ -1518,17 +1541,63 @@ class DatasetSeriesWrapper(EOMetadataWrapper, ResourceWrapper):
             begin_time = min([t.timestamp_begin for t in eo_metadata_set])
             end_time = max([t.timestamp_end for t in eo_metadata_set])
         
-        footprint = eo_metadata_set.aggregate(
-            Union('footprint')
-        )["footprint__union"]
+        try:
+            # use the aggregate calculation if provided
+            footprint = MultiPolygon(
+                Polygon.from_bbox(eo_metadata_set.extent(field_name="footprint"))
+            )
+        except:
+            # manual collection of footprints (required for backends other than 
+            # SpatiaLite or PostGIS)
+            logger.warn("Performing manual envelope calculation.")
+            envelopes = MultiPolygon([
+                md.footprint.envelope for md in eo_metadata_set
+            ])
+            footprint = envelopes.envelope
         
         return (begin_time, end_time, footprint)
     
-    def _updateMetadata(self):
+    def _updateMetadata(self, added_coverage=None):
         begin_time = None
-        footprint = self.__model.eo_metadata.footprint
+        footprint = None
         
         rect_qs = self.__model.rect_datasets.all()
+        ref_qs = self.__model.ref_datasets.all()
+        mosaic_qs = self.__model.rect_stitched_mosaics.all()
+        
+        # if a coverage was added, do not accumulate metadata, instead make a
+        # simplified approach and only add the metadata of the new coverage
+        if added_coverage:
+            eo_metadata = self.__model.eo_metadata
+            sum_count = rect_qs.count() + ref_qs.count() + mosaic_qs.count()
+            
+            # only perform shortcut when there is guranteed metadata of 
+            # included coverages
+            if sum_count > 1:
+                logger.info("Performing shortcut metadata calculation.")
+                eo_metadata.timestamp_begin = min(
+                    eo_metadata.timestamp_begin, added_coverage.getBeginTime()
+                )
+                eo_metadata.timestamp_end = max(
+                    eo_metadata.timestamp_end, added_coverage.getEndTime()
+                )
+                
+                # calculate a new combined envelope if necessary 
+                new_envelope = added_coverage.getFootprint().envelope
+                series_envelopes = eo_metadata.footprint
+                if not series_envelopes.contains(new_envelope):
+                    series_envelopes.append(new_envelope)
+                    eo_metadata.footprint = MultiPolygon(
+                        series_envelopes.envelope
+                    )
+                
+                eo_metadata.full_clean()
+                eo_metadata.save()
+                
+                # exit now
+                return
+        
+        # perform the normal metadata aggregation here
         if len(rect_qs):
             eo_metadata_set = EOMetadataRecord.objects.filter(
                 rectifieddatasetrecord_set__in = rect_qs
@@ -1538,7 +1607,7 @@ class DatasetSeriesWrapper(EOMetadataWrapper, ResourceWrapper):
                 eo_metadata_set
             )
 
-        ref_qs = self.__model.ref_datasets.all()
+        
         if len(ref_qs):
             eo_metadata_set = EOMetadataRecord.objects.filter(
                 referenceabledatasetrecord_set__in = ref_qs
@@ -1557,7 +1626,7 @@ class DatasetSeriesWrapper(EOMetadataWrapper, ResourceWrapper):
                 end_time = end_time_ref
                 footprint = footprint_ref
 
-        mosaic_qs = self.__model.rect_stitched_mosaics.all()
+        
         if len(mosaic_qs):
             eo_metadata_set = EOMetadataRecord.objects.filter(
                 rectifiedstitchedmosaicrecord_set__in = mosaic_qs
@@ -1578,6 +1647,8 @@ class DatasetSeriesWrapper(EOMetadataWrapper, ResourceWrapper):
 
         if footprint and footprint.geom_type.upper() != "MULTIPOLYGON":
             footprint = MultiPolygon(footprint)
+        elif footprint is None:
+            pass
 
         # if there are no children do not update the metadata
         if begin_time:
@@ -1585,6 +1656,7 @@ class DatasetSeriesWrapper(EOMetadataWrapper, ResourceWrapper):
             self.__model.eo_metadata.timestamp_end = end_time
             self.__model.eo_metadata.footprint = footprint
             
+            self.__model.eo_metadata.full_clean()
             self.__model.eo_metadata.save()
             
     #-------------------------------------------------------------------
@@ -1631,6 +1703,15 @@ class DatasetSeriesWrapper(EOMetadataWrapper, ResourceWrapper):
             filter_exprs = filter_exprs
         )
         
+    def getLayerMetadata(self):
+        """
+        Returns a list of ``(metadata_key, metadata_value)`` pairs
+        that represent MapServer metadata tags to be attached to
+        MapServer layers.
+        """
+        
+        return self.__model.layer_metadata.values_list("key", "value")
+        
     def contains(self, wrapper):
         """
         This method returns ``True`` if the Dataset Series contains
@@ -1670,7 +1751,7 @@ class DatasetSeriesWrapper(EOMetadataWrapper, ResourceWrapper):
             )
         
         if not self.__block_md_update:
-            self._updateMetadata()
+            self._updateMetadata(wrapper)
 
     def removeCoverage(self, wrapper):
         """
