@@ -1,5 +1,5 @@
 #-------------------------------------------------------------------------------
-# $Id: subset.py 1260 2012-02-10 18:30:16Z meissls $
+# $Id$
 #
 # Project: EOxServer <http://eoxserver.org>
 # Authors: Stephan Krause <stephan.krause@eox.at>
@@ -27,13 +27,17 @@
 # THE SOFTWARE.
 #-------------------------------------------------------------------------------
 
+"""
+This module provides utilities for handling WCS 2.0 subset expressions.
+"""
+
 import re
 from django.contrib.gis.geos import Polygon
 
 from eoxserver.core.system import System
 from eoxserver.core.exceptions import InvalidExpressionError
 from eoxserver.core.util.timetools import getDateTime
-from eoxserver.core.util.geotools import getSRIDFromCRSURI
+from eoxserver.resources.coverages import crss 
 from eoxserver.resources.coverages.filters import (
     BoundedArea, Slice, TimeInterval
 )
@@ -43,6 +47,19 @@ from eoxserver.services.exceptions import (
 )
 
 class WCS20SubsetDecoder(object):
+    """
+    This class provides methods for decoding a subset expression according
+    to WCS 2.0.0. Note that in WCS 2.0.1 the syntax and semantics of these
+    subset expressions have changed quite considerably, especially for the
+    GET KVP encoding. These are not yet supported.
+    
+    The constructor takes two arguments. The first one, ``req`` is required
+    and shall contain a :class:`~.OWSRequest` instance. The ``default_crs_id``
+    parameter is optional and may contain a CRS ID that will be used as
+    fallback if no CRS is specified in the subset expression itself. The
+    CRS ID can be either the string ``"imageCRS"`` or an integer EPSG ID of
+    a CRS.
+    """
     def __init__(self, req, default_crs_id=None):
         self.req = req
         self.default_crs_id = default_crs_id
@@ -101,15 +118,28 @@ class WCS20SubsetDecoder(object):
         trim_elements = self.req.getParamValue("trims")
         
         for slice_element in slice_elements:
-            axis_label = slice_element.getElementsByTagName("wcs:Dimension")[0].firstChild.data
+            dimension = slice_element.getElementsByTagName("wcs:Dimension")[0]
+            axis_label = dimension.firstChild.data
+            
+            # TODO: until the WCS 2.0 CRS extension is finished we have to use the
+            # MapServer way to parse the CRS from the Trim/Slice
             crs = None
+            if dimension.hasAttribute("crs"):
+                crs = dimension.getAttribute("crs")
+            
             slice_point = slice_element.getElementsByTagName("wcs:SlicePoint")[0].firstChild.data
             
             slices.append((axis_label, crs, slice_point))
             
         for trim_element in trim_elements:
-            axis_label = trim_element.getElementsByTagName("wcs:Dimension")[0].firstChild.data
+            dimension = trim_element.getElementsByTagName("wcs:Dimension")[0]
+            axis_label = dimension.firstChild.data
+            
+            # TODO: see above
             crs = None
+            if dimension.hasAttribute("crs"):
+                crs = dimension.getAttribute("crs")
+            
             trim_low = trim_element.getElementsByTagName("wcs:TrimLow")[0].firstChild.data
             trim_high = trim_element.getElementsByTagName("wcs:TrimHigh")[0].firstChild.data
         
@@ -172,25 +202,21 @@ class WCS20SubsetDecoder(object):
         )
         
     def _getSpatialSliceExpression(self, slice):
-        axis_label = slice[0]
-        
-        if slice[1] is None:
+        axis_label , crs_id_str , slice_point_str = slice[:3]
+
+        if crs_id_str is None:
             crs_id = self.default_crs_id
         else:
-            try:
-                crs_id = getSRIDFromCRSURI(slice[1])
-            except:
-                raise InvalidSubsettingException(
-                    "Unrecognized CRS URI '%s'" % slice[1]
-                )
-        
+            crs_id = crss.parseEPSGCode(crs_id_str,(crss.fromURL,crss.fromURN))
+            if crs_id is None:
+                raise InvalidSubsettingException( "Failed to extrac an EPSG"
+                    " code from the CRS URI '%s'!" % crs_id_str )
+                
         try:
-            slice_point = float(slice[2])
-        except:
-            raise InvalidSubsettingException(
-                "Could not convert slice point token '%s' to number." %\
-                slice[2]
-            )
+            slice_point = float(slice_point_str)
+        except ValueError:
+            raise InvalidSubsettingException( "Failed to convert slice point"
+                " '%s' to a real number." % slice_point_str )
         
         return System.getRegistry().getFromFactory(
             "resources.coverages.filters.CoverageExpressionFactory",
@@ -212,7 +238,7 @@ class WCS20SubsetDecoder(object):
         elif self.containment.lower() == "contains":
             op_part = "within"
         else:
-            raise InvalidParameterException(
+            raise InvalidRequestException(
                 "Unknown containment mode '%s'." % self.containment
             )
         
@@ -365,15 +391,16 @@ class WCS20SubsetDecoder(object):
                     "Cannot convert token '%s' to integer." % token
                 )
     
-    def _getCRSID(self, crs_expr):
-        if crs_expr is None:
-            return self.default_crs_id
+    def _getCRSID(self, crs_id_str):
+        if crs_id_str is None:
+            crs_id = self.default_crs_id
         else:
-            try:
-                return getSRIDFromCRSURI(crs_expr)
-            except Exception, e:
-                raise InvalidSubsettingException(e.msg)
-    
+            crs_id = crss.parseEPSGCode(crs_id_str,(crss.fromURL,crss.fromURN)) 
+            if crs_id is None:
+                raise InvalidSubsettingException( "Failed to extract an EPSG"
+                    " code from the CRS URI '%s'!" % crs_id_str )
+        return crs_id 
+
     def _get_image_extent(self, x_bounds, y_bounds, x_size, y_size):
         if x_bounds[0] == "unbounded":
             minx = 0
@@ -424,6 +451,28 @@ class WCS20SubsetDecoder(object):
         return (minx, miny, maxx, maxy)
     
     def getFilterExpressions(self):
+        """
+        This method returns a list of filter expressions based on the subset
+        expression. These filter expressions can be used to select coverages
+        from the database.
+        
+        Depending on the types of the subset expressions
+        :class:`~.SpatialSliceExpression`,
+        :class:`~.FootprintIntersectsAreaExpression`,
+        :class:`~.FootprintWithinAreaExpression`,
+        :class:`~.TimeSliceExpression`,
+        :class:`~.IntersectingTimeIntervalExpression` or
+        :class:`~.ContainingTimeIntervalExpression` instances will be returned.
+        
+        The return values depend on the ``subset`` as well as the
+        ``containment`` parameters contained in the request.
+        
+        This method raises :exc:`~.InvalidRequestException` if the subset
+        expression syntax is found to be invalid. It raises
+        :exc:`~.InvalidSubsettingException` if the subset expression is
+        syntactically correct, but cannot be interpretated, e.g. because of
+        wrong date/time, number or spatial reference formats.
+        """
         self._decode()
         
         filter_exprs = []
@@ -435,6 +484,33 @@ class WCS20SubsetDecoder(object):
         return filter_exprs
     
     def getBoundingPolygon(self, footprint, srid, size_x, size_y, extent):
+        """
+        This method returns a GeoDjango :class:`Polygon` object computed from
+        the subset expression as well as the submitted parameters. The
+        ``footprint`` contains the footprint of the underlying coverage,
+        the ``srid`` is the integer EPSG ID of the coverage CRS, ``size_x`` and
+        ``size_y`` denote the size of the coverage in pixels and ``extent`` is
+        the well-known 4-tuple ``(minx, miny, maxx, maxy)``.
+        
+        In case the CRS ID of the subsets relates to the image CRS, the
+        bounding polygon is the intersection of the subset trims and the
+        coverage extent expressed in the coverage CRS denoted by ``srid``.
+        The pixel coordinates in the subset statements are computed using the
+        ``extent``, ``size_x`` and ``size_y`` parameters.
+        
+        In case the CRS ID of the subsets is an EPSG ID denoting a CRS the
+        bounding polygon is computed from the footprint and the subset trims.
+        The CRS of the polygon is the one used in the subset expressions, not
+        necessarily the native CRS of the coverage. It corresponds to the
+        intersection of the bounding box of the footprint transformed into the
+        subset CRS and the subset trims.
+        
+        This method raises :exc:`~.InvalidRequestException` if the subset
+        expression syntax is found to be invalid. It raises
+        :exc:`~.InvalidSubsettingException` if the subset expression is
+        syntactically correct, but cannot be interpretated, e.g. because of
+        wrong date/time, number or spatial reference formats.
+        """
         self._decode()
         
         time_intv, crs_id, x_bounds, y_bounds = \
@@ -506,6 +582,28 @@ class WCS20SubsetDecoder(object):
         return poly
 
     def getSubset(self, x_size, y_size, footprint):
+        """
+        This method returns a :class:`~.BoundedArea` object containing the
+        bounding coordinates described by the subsets. The ``x_size`` and
+        ``y_size`` parameters describe the pixel size of the coverage. The
+        ``footprint`` argument is the coverage footprint as GeoDjango geometry.
+        If there are no trim statements contained in the subset expressions
+        ``None`` is returned.
+        
+        Depending on the CRS ID used in the subset expressions, the result
+        may contain pixel coordinates (imageCRS) or coordinates expressed in
+        the CRS of the subset expression. In the former case, the returned area
+        corresponds to the intersection of the pixel ranges defined by the trims
+        and the size of the coverage. In the latter case the bounded area
+        corresponds to the intersection of the subset with the bounding box of
+        the footprint in the subset CRS.
+        
+        This method raises :exc:`~.InvalidRequestException` if the subset
+        expression syntax is found to be invalid. It raises
+        :exc:`~.InvalidSubsettingException` if the subset expression is
+        syntactically correct, but cannot be interpretated, e.g. because of
+        wrong date/time, number or spatial reference formats.
+        """
         self._decode()
         
         time_intv, crs_id, x_bounds, y_bounds = \
