@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------
-# $Id: wcst11ActionUpdateAll.py 1266 2012-02-12 14:32:48Z meissls $
+# $Id$
 #
 # Description: 
 #
@@ -36,12 +36,14 @@ import os
 import sys 
 import os.path
 import traceback
-
 import logging
 import shutil
 
 from wcst11ActionCommon import ExActionFailed
 
+
+logger = logging.getLogger(__name__)
+
 #-------------------------------------------------------------------------------
 
 # ACTION: UPDATE ALL
@@ -49,12 +51,14 @@ from wcst11ActionCommon import ExActionFailed
 def wcst11ActionUpdateAll( action , context ) : 
 
     aname = action["Action"]
-    logging.debug( "WCSt11:%s: START" % aname ) 
+    logger.debug( "WCSt11:%s: START" % aname ) 
+
+    # extract user provided CID 
+    #coverageId = action["Identifier"] 
 
     # action not implemented 
-
     msg = "WCSt11:%s: Action not implemented!" % aname 
-    logging.error( msg ) 
+    logger.error( msg ) 
     raise ExActionFailed , msg 
 
-    return coverageId
+    #return coverageId
