@@ -1,10 +1,11 @@
 #-------------------------------------------------------------------------------
-# $Id: testbase.py 2145 2012-11-27 22:25:20Z meissls $
+# $Id$
 #
 # Project: EOxServer <http://eoxserver.org>
 # Authors: Stephan Krause <stephan.krause@eox.at>
 #          Stephan Meissl <stephan.meissl@eox.at>
 #          Fabian Schindler <fabian.schindler@eox.at>
+#          Martin Paces <martin.paces@eox.at>
 #
 #-------------------------------------------------------------------------------
 # Copyright (C) 2011 EOX IT Services GmbH
@@ -28,28 +29,38 @@
 # THE SOFTWARE.
 #-------------------------------------------------------------------------------
 
+import re 
 import os.path
 import logging
 from lxml import etree
 import tempfile
 import mimetypes
-import email
-from osgeo import gdal, gdalconst, osr
+from cStringIO import StringIO
 
 from django.test import Client
 from django.conf import settings
-from django.db import connection
 
 from eoxserver.core.system import System
 from eoxserver.core.util.xmltools import XMLDecoder
-from eoxserver.testing.core import (
-    EOxServerTestCase, EOxServerTransactionTestCase, BASE_FIXTURES
+from eoxserver.core.util.multiparttools import (
+    mpUnpack, getMimeType, getMultipartBoundary
 )
+from eoxserver.contrib import gdal, osr
+from eoxserver.testing.core import (
+    EOxServerTestCase, BASE_FIXTURES
+)
+from eoxserver.testing.xcomp import xmlCompareFiles
+
+
+logger = logging.getLogger(__name__)
 
 # THIS IS INTENTIONALLY DOUBLED DUE TO A BUG IN MIMETYPES!
 mimetypes.init()
 mimetypes.init()
 
+# precompile regular expression
+RE_MIME_TYPE_XML = re.compile("^text/xml|application/(?:[a-z]+\+)?xml$",re.IGNORECASE)
+
 #===============================================================================
 # Helper functions
 #===============================================================================
@@ -68,30 +79,25 @@ def resolution_from_ds(ds):
     gt = ds.GetGeoTransform()
     return (gt[1], abs(gt[5]))
 
+def _getMime( s ) : 
+    return s.partition(';')[0].strip().lower() 
 #===============================================================================
 # Common classes
 #===============================================================================
 
-class OWSMixIn(object):
+class OWSTestCase(EOxServerTestCase):
+
     """ Main base class for testing the OWS interface
         of EOxServer.
     """
     
     fixtures = BASE_FIXTURES + ["testing_coverages.json", "testing_asar.json"]
-    requires_fixed_db = False
     
     def setUp(self):
-        super(OWSMixIn,self).setUp()
+        super(OWSTestCase,self).setUp()
         
-        logging.info("Starting Test Case: %s" % self.__class__.__name__)
+        logger.info("Starting Test Case: %s" % self.__class__.__name__)
         
-        if settings.DATABASES["default"]["NAME"] == ":memory:" and self.requires_fixed_db:
-            self.skipTest("This test requires a file database; set 'TEST_NAME' "
-                          "in your default database settings to enable this test.")
-        elif self.requires_fixed_db and settings.DATABASES["default"]["ENGINE"] == "django.contrib.gis.db.backends.spatialite":
-            cursor = connection.cursor()
-            cursor.execute("PRAGMA SYNCHRONOUS;")
-
         rq = self.getRequest()
 
         if ( len(rq) == 2 ):
@@ -129,10 +135,10 @@ class OWSMixIn(object):
         return "xml"
     
     def getResponseFileDir(self):
-        return os.path.join("../autotest","responses")
+        return os.path.join(settings.PROJECT_DIR,"responses")
 
     def getDataFileDir(self):
-        return os.path.join("../autotest","data")
+        return os.path.join(settings.PROJECT_DIR,"data")
     
     def getResponseFileName(self, file_type):
         return "%s.%s" % (self.__class__.__name__, self.getFileExtension(file_type))
@@ -141,15 +147,41 @@ class OWSMixIn(object):
         return self.response.content
     
     def getExpectedFileDir(self):
-        return os.path.join("../autotest", "expected")
+        return os.path.join(settings.PROJECT_DIR, "expected")
     
     def getExpectedFileName(self, file_type):
         return "%s.%s" % (self.__class__.__name__, self.getFileExtension(file_type))
     
+    def getXMLData(self):
+        raise Exception("Not implemented.")
+    
+    def _testXMLComparison( self , suffix = "xml" , response = None ): 
+        """
+        Helper function for the basic XML tree comparison to be used by `testXMLComparison`.
+        """
+        expected_path = os.path.join( self.getExpectedFileDir(), self.getExpectedFileName(suffix) )
+        response_path = os.path.join( self.getResponseFileDir(), self.getResponseFileName(suffix) )
+        
+        # store the XML response 
+        if response is None : response = self.getXMLData()
+        
+        # check that the expected XML response exists 
+        if not os.path.isfile( expected_path ) : 
+            with file(response_path, 'w') as fid : fid.write(response)
+            self.skipTest( "Missing the expected XML response '%s'." % expected_path )
+        
+        # perform the actual comparison 
+        try: 
+            xmlCompareFiles( expected_path , StringIO(response) ) 
+        except Exception as e : 
+            with file(response_path, 'w') as fid : fid.write(response)
+            self.fail( "Response returned in '%s' is not equal to expected response in '%s'. REASON: %s " % \
+                    ( response_path , expected_path , str(e) ) )
+
+
     def _testBinaryComparison(self, file_type, Data=None):
         """
-        Helper function for the `testBinaryComparisonXML` and
-        `testBinaryComparisonRaster` functions.
+        Helper function for the `testBinaryComparisonRaster` function.
         """
         expected_path = os.path.join(self.getExpectedFileDir(), self.getExpectedFileName(file_type))
         response_path = os.path.join(self.getResponseFileDir(), self.getResponseFileName(file_type))
@@ -187,17 +219,12 @@ class OWSMixIn(object):
                 )
     
     def testStatus(self):
-        logging.info("Checking HTTP Status ...")
+        logger.info("Checking HTTP Status ...")
+        #pylint: disable=E1103
         self.assertEqual(self.response.status_code, 200)
 
-class OWSTestCase(OWSMixIn, EOxServerTestCase):
-    pass
 
-class OWSTransactionTestCase(OWSMixIn, EOxServerTransactionTestCase):
-    pass
-
-
-class RasterMixIn(object):
+class RasterTestCase(OWSTestCase):
     """
     Base class for test cases that expect a raster as response.
     """
@@ -210,11 +237,6 @@ class RasterMixIn(object):
             self.skipTest("Binary raster comparison is explicitly disabled.")
         self._testBinaryComparison("raster")
 
-class RasterTestCase(RasterMixIn, OWSTestCase):
-    pass
-
-class RasterTransactionTestCase(RasterMixIn, OWSTransactionTestCase):
-    pass
 
 class GDALDatasetTestCase(RasterTestCase):
     """
@@ -241,12 +263,12 @@ class GDALDatasetTestCase(RasterTestCase):
         exp_path = os.path.join(self.getExpectedFileDir(), self.getExpectedFileName("raster"))
         
         try:
-            self.res_ds = gdal.Open(self.tmppath, gdalconst.GA_ReadOnly)
+            self.res_ds = gdal.Open(self.tmppath, gdal.GA_ReadOnly)
         except RuntimeError, e:
             self.fail("Response could not be opened with GDAL. Error was %s" % e)
         
         try:
-            self.exp_ds = gdal.Open(exp_path, gdalconst.GA_ReadOnly)
+            self.exp_ds = gdal.Open(exp_path, gdal.GA_ReadOnly)
         except RuntimeError:
             self.skipTest("Expected response in '%s' is not present" % exp_path)
 
@@ -319,7 +341,7 @@ class XMLTestCase(OWSTestCase):
         return self.response.content
     
     def testValidate(self, XMLData=None):
-        logging.info("Validating XML ...")
+        logger.info("Validating XML ...")
         
         if XMLData is None:
             doc = etree.XML(self.getXMLData())
@@ -354,8 +376,49 @@ class XMLTestCase(OWSTestCase):
         except etree.Error as e:
             self.fail(str(e))
         
-    def testBinaryComparisonXML(self):
-        self._testBinaryComparison("xml")
+    def testXMLComparison(self):
+        self._testXMLComparison()
+
+class SchematronTestMixIn(object): # requires to be mixed in with XMLTestCase
+    """
+    Mixin class for XML test cases that uses XML schematrons for validation.
+    Use the `schematron_locations`
+    """
+    schematron_locations = ()
+    
+    def testSchematron(self):
+        errors = []
+        doc = etree.XML(self.getXMLData())
+        
+        schematron_def = etree.Element("schema", attrib={
+                "queryBinding": "xslt2",
+            }, nsmap={
+                None: "http://purl.oclc.org/dsdl/schematron"
+            }
+        )
+        etree.SubElement(schematron_def, "pattern")
+        
+# TODO: Check if this is even possible:
+#        for ns, location in zip(self.schematron_locations[::2], self.schematron_locations[1::2]):
+#            etree.SubElement(schematron_def, "import", attrib={
+#                    "namespace": ns,
+#                    "schemaLocation": location
+#                }
+#            )
+        
+        # TODO: ugly workaround. But otherwise, the doc is not recognized as schema
+        schematron = etree.Schematron(etree.XML(etree.tostring(schematron_def)))
+                    
+        try:
+            schematron.assertValid(doc)
+        except etree.DocumentInvalid, e:
+            errors.append(str(e))
+        except etree.SchematronValidateError:
+            self.skipTest("Schematron Testing is not enabled.")
+
+        if len(errors):
+            self.fail(str(errors))
+
 
 class ExceptionTestCase(XMLTestCase):
     """
@@ -373,21 +436,25 @@ class ExceptionTestCase(XMLTestCase):
         return "/ows:Exception/@exceptionCode"
         
     def testStatus(self):
-        logging.info("Checking HTTP Status ...")
+        logger.info("Checking HTTP Status ...")
+        #pylint: disable=E1103
         self.assertEqual(self.response.status_code, self.getExpectedHTTPStatus())
     
     def testExceptionCode(self):
-        logging.info("Checking OWS Exception Code ...")
+        logger.info("Checking OWS Exception Code ...")
         decoder = XMLDecoder(self.getXMLData(), {
             "exceptionCode": {"xml_location": self.getExceptionCodeLocation(), "xml_type": "string"}
         })
         self.assertEqual(decoder.getValue("exceptionCode"), self.getExpectedExceptionCode())      
 
-class HTMLTransactionTestCase(OWSTransactionTestCase):
+class HTMLTestCase(OWSTestCase):
     """
     HTML test cases expect to receive HTML text.
     """
     
+    def getFileExtension(self, file_type):
+        return "html"
+    
     def testBinaryComparisonHTML(self):
         self._testBinaryComparison("html")
 
@@ -405,41 +472,86 @@ class MultipartTestCase(XMLTestCase):
         
         self._setUpMultiparts()
     
+
+    def _mangleXML( self , cbuffer ) : 
+        """ remove variable parts of selected XML elements text and attributes """ 
+
+        #define XML names to be used 
+
+        N0 = "{http://www.opengis.net/gml/3.2}rangeSet/" \
+             "{http://www.opengis.net/gml/3.2}File/" \
+             "{http://www.opengis.net/gml/3.2}rangeParameters"
+
+        N1 = "{http://www.opengis.net/gml/3.2}rangeSet/" \
+             "{http://www.opengis.net/gml/3.2}File/" \
+             "{http://www.opengis.net/gml/3.2}fileReference"
+
+        N2 = "{http://www.opengis.net/wcs/1.1}Coverage/" \
+             "{http://www.opengis.net/ows/1.1}Reference"
+
+        HREF  = "{http://www.w3.org/1999/xlink}href"
+
+        # define handy closures 
+
+        def cropFileName( name ) : 
+            base , _ , ext = name.rpartition(".")
+            base , _ , _   = base.rpartition("_")
+            return "%s.%s"%(base,ext) 
+
+        def changeHref( e ) : 
+            if e is not None : e.set( HREF , cropFileName( e.get( HREF ) ) )
+                
+        def changeText( e ) : 
+            if e is not None: e.text = cropFileName( e.text )
+
+        # parse XML Note: etree.parse respects the encoding reported in XML delaration!
+        xml = etree.parse( StringIO( cbuffer ) )
+
+        # mangle XML content to get rid of variable content
+
+        # WCS 2.0.x - rangeSet/File
+        changeHref( xml.find( N0 ) ) 
+        changeText( xml.find( N1 ) )
+        # WCS 1.1.x - Coverage/Reference 
+        changeHref( xml.find( N2 ) ) 
+
+        # output xml - force UTF-8 encoding including the XML delaration 
+        return etree.tostring( xml , encoding="UTF-8" , xml_declaration=True )
+
+    def _unpackMultipartContent( self , response ) : 
+
+        content      = response.content
+        content_type = response['Content-Type']
+
+        # check the content type 
+        if getMimeType( content_type ) \
+            not in ( "multipart/mixed" , "multipart/related" ) :
+            raise Exception , "Received content is neither mixed nor related multipart! Content-Type: %s" % content_type 
+
+        # extract multipart boundary  
+        boundary = getMultipartBoundary( content_type ) 
+        
+        # unpack the multipart content 
+        for header,offset,size in mpUnpack(content,boundary) :
+            match = RE_MIME_TYPE_XML.match( _getMime(header['content-type']) ) 
+            if match is not None : 
+                # store XML response 
+                self.xmlData = content[offset:(offset+size)]
+            else : 
+                # store coverage data 
+                self.imageData = content[offset:(offset+size)]
+
+
     def _setUpMultiparts(self):
         if self.isSetUp: return
-        response_msg = email.message_from_string("Content-type: multipart/mixed; boundary=wcs\n\n"
-                                                 + self.response.content)
-        
-        for part in response_msg.walk():
-            if part['Content-type'] == "multipart/mixed; boundary=wcs":
-                continue
-            elif part['Content-type'] in ("text/xml", "application/gml+xml"):
-                # The filename depends on the actual time the request was 
-                # answered. It has to be explicitly unified.
-                tree = etree.fromstring(part.get_payload())
-                # WCS 2.0
-                node = tree.find("{http://www.opengis.net/gml/3.2}rangeSet/" \
-                                 "{http://www.opengis.net/gml/3.2}File/" \
-                                 "{http://www.opengis.net/gml/3.2}rangeParameters")
-                # WCS 11
-                if node is None:
-                    node = tree.find("{http://www.opengis.net/wcs/1.1}Coverage/" \
-                                     "{http://www.opengis.net/ows/1.1}Reference")
 
-                if node is not None:
-                    filename = node.get("{http://www.w3.org/1999/xlink}href").rsplit("_",1)[0] + ".tif"
-                    node.set("{http://www.w3.org/1999/xlink}href", filename)
-                    node2 = tree.find("{http://www.opengis.net/gml/3.2}rangeSet/" \
-                                     "{http://www.opengis.net/gml/3.2}File/" \
-                                     "{http://www.opengis.net/gml/3.2}fileReference")
-                    if node2 is not None:
-                        node2.text = filename
-
-                self.xmlData = etree.tostring(tree, encoding="ISO-8859-1")
-            else:
-                self.imageData = part.get_payload()
+        self._unpackMultipartContent( self.response ) 
         
+        # mangle XML data 
+        if self.xmlData : self.xmlData = self._mangleXML( self.xmlData ) 
+
         self.isSetUp = True
+
     
     def getFileExtension(self, part=None):
         if part == "xml":
@@ -484,11 +596,13 @@ class WCSTransactionTestCase(XMLTestCase):
     Base class for WCS Transactional test cases.
     """
     ADDmetaFile = None
+    ADDtiffFile = None
     isAsync = False
+    ID = None
 
     def setUp(self):
         super(WCSTransactionTestCase, self).setUp()
-        logging.debug("WCSTransactionTestCase for ID: %s" % self.ID)
+        logger.debug("WCSTransactionTestCase for ID: %s" % self.ID)
         
         if self.isAsync:
             from eoxserver.resources.processes.tracker import (
@@ -578,7 +692,7 @@ class WCSTransactionTestCase(XMLTestCase):
     def getDataFullPath(self , path_to):
         return os.path.abspath( os.path.join( self.getDataFileDir() , path_to) )
 
-    def testBinaryComparisonXML(self):
+    def testXMLComparison(self):
         # the TimeStamp and RequestId elements are set during ingestion and 
         # thus have to be explicitly unified
         tree = etree.fromstring(self.getXMLData())
@@ -587,14 +701,14 @@ class WCSTransactionTestCase(XMLTestCase):
         for node in tree.findall("{http://www.opengis.net/wcs/1.1/wcst}TimeStamp"):
             node.text = "2011-01-01T00:00:00Z"
         self.response.content = etree.tostring(tree, encoding="ISO-8859-1")
-        super(WCSTransactionTestCase, self).testBinaryComparisonXML()
+        super(WCSTransactionTestCase, self).testXMLComparison()
 
     def testResponseIdComparisonAdd(self):
         """
         Tests that the <ows:Identifier> in the XML request and response is the 
         same
         """
-        logging.debug("IDCompare testResponseIdComparison for ID: %s" % self.ID)
+        logger.debug("IDCompare testResponseIdComparison for ID: %s" % self.ID)
         self._testResponseIdComparison( self.ID  , self.getXMLData()  )
 
     def testStatusDescribeCoverage(self):
@@ -602,41 +716,46 @@ class WCSTransactionTestCase(XMLTestCase):
         Tests that the inserted coverage is available in a DescribeCoverage
         request
         """
+        #pylint: disable=E1103
         self.assertEqual(self.responseDescribeCoverage.status_code, 200)
 
     def testValidateDescribeCoverage(self):
         self.testValidate(self.responseDescribeCoverage.content)
 
-    def testBinaryComparisonXMLDescribeCoverage(self):
-        self._testBinaryComparison("TransactionDescribeCoverage", self.responseDescribeCoverage.content)
+    def testXMLComparisonDescribeCoverage(self):
+        #self._testBinaryComparison("TransactionDescribeCoverage", self.responseDescribeCoverage.content)
+        self._testXMLComparison( "TransactionDescribeCoverage" , self.responseDescribeCoverage.content ) 
 
     def testStatusGetCoverage(self):
         """
         Validate the inserted coverage via a GetCoverage request
         """
+        #pylint: disable=E1103
         self.assertEqual(self.responseGetCoverage.status_code, 200)
 
     def testStatusDeleteCoverage(self):
         """
         Test to delete the previously inserted coaverage
         """
+        #pylint: disable=E1103
         self.assertEqual(self.responseDeleteCoverage.status_code, 200)
 
     def testValidateDeleteCoverage(self):
         self.testValidate(self.responseDeleteCoverage.content)
 
-    def testBinaryComparisonXMLDeleteCoverage(self):
+    def testXMLComparisonDeleteCoverage(self):
         tree = etree.fromstring(self.responseDeleteCoverage.content)
         for node in tree.findall("{http://www.opengis.net/wcs/1.1/wcst}RequestId"):
             node.text = "identifier"
-        self._testBinaryComparison("TransactionDeleteCoverage", etree.tostring(tree, encoding="ISO-8859-1"))
+        #self._testBinaryComparison("TransactionDeleteCoverage", etree.tostring(tree, encoding="ISO-8859-1"))
+        self._testXMLComparison( "TransactionDeleteCoverage" , etree.tostring(tree, encoding="ISO-8859-1"))
 
     def testResponseIdComparisonDelete(self):
         """
         Tests that the <ows:Identifier> in the XML request and response is the 
         same
         """
-        logging.debug("IDCompare testResponseIdComparison for ID: %s" % self.ID)
+        logger.debug("IDCompare testResponseIdComparison for ID: %s" % self.ID)
         self._testResponseIdComparison( self.ID , self.responseDeleteCoverage.content )
 
     def testStatusDescribeCoverageDeleted(self):
@@ -644,20 +763,22 @@ class WCSTransactionTestCase(XMLTestCase):
         Tests that the deletec coverage is not longer available in a 
         DescribeCoverage request
         """
+        #pylint: disable=E1103
         self.assertEqual(self.responseDescribeCoverageDeleted.status_code, 404)
 
     def testValidateDescribeCoverageDeleted(self):
         self.testValidate(self.responseDescribeCoverageDeleted.content)
 
-    def testBinaryComparisonXMLDescribeCoverageDeleted(self):
-        self._testBinaryComparison("TransactionDescribeCoverageDeleted", self.responseDescribeCoverageDeleted.content)
+    def testXMLComparisonDescribeCoverageDeleted(self):
+        #self._testBinaryComparison("TransactionDescribeCoverageDeleted", self.responseDescribeCoverageDeleted.content)
+        self._testXMLComparison( "TransactionDescribeCoverageDeleted" , self.responseDescribeCoverageDeleted.content )
 
     def _testResponseIdComparison(self , id , rcontent ):
         """
         Tests that the <ows:Identifier> in the XML request and response is the 
         same
         """
-        logging.debug("_testResponseIdComparison for ID: %s" % id)
+        logger.debug("_testResponseIdComparison for ID: %s" % id)
         tree = etree.fromstring( rcontent )
         for node in tree.findall("{http://www.opengis.net/ows/1.1}Identifier"):
             self.assertEqual( node.text, id )
@@ -673,16 +794,8 @@ class WCSTransactionRectifiedGridCoverageTestCase(
     # in MultipartTestCase tests
     def _setUpMultiparts(self):
         if self.isSetUp: return
-        response_msg = email.message_from_string("Content-type: multipart/mixed; boundary=wcs\n\n"
-                                                 + self.responseGetCoverage.content)
-        
-        for part in response_msg.walk():
-            if part['Content-type'] == "multipart/mixed; boundary=wcs":
-                continue
-            elif part['Content-type'] == "text/xml":
-                self.xmlData = part.get_payload()
-            else:
-                self.imageData = part.get_payload()
+
+        self._unpackMultipartContent( self.responseGetCoverage ) 
 
         self.isSetUp = True
 
@@ -700,16 +813,8 @@ class WCSTransactionReferenceableGridCoverageTestCase(
     # in MultipartTestCase tests
     def _setUpMultiparts(self):
         if self.isSetUp: return
-        response_msg = email.message_from_string("Content-type: multipart/mixed; boundary=wcs\n\n"
-                                                 + self.responseGetCoverage.content)
-        
-        for part in response_msg.walk():
-            if part['Content-type'] == "multipart/mixed; boundary=wcs":
-                continue
-            elif part['Content-type'] == "text/xml":
-                self.xmlData = part.get_payload()
-            else:
-                self.imageData = part.get_payload()
+
+        self._unpackMultipartContent( self.responseGetCoverage ) 
 
         self.isSetUp = True
 
@@ -725,7 +830,7 @@ class WCS20DescribeEOCoverageSetSubsettingTestCase(XMLTestCase):
         return []
     
     def testCoverageIds(self):
-        logging.info("Checking Coverage Ids ...")
+        logger.info("Checking Coverage Ids ...")
         decoder = XMLDecoder(self.getXMLData(), {
             "coverageids": {"xml_location": "/wcs:CoverageDescriptions/wcs:CoverageDescription/wcs:CoverageId", "xml_type": "string[]"}
         })
@@ -761,7 +866,7 @@ class WCS20DescribeEOCoverageSetSectionsTestCase(XMLTestCase):
         self.assertItemsEqual(sections, self.getExpectedSections())
     
 class WCS20GetCoverageMultipartTestCase(MultipartTestCase):
-    def testBinaryComparisonXML(self):
+    def testXMLComparison(self):
         # The timePosition tag depends on the actual time the request was 
         # answered. It has to be explicitly unified.
         tree = etree.fromstring(self.getXMLData())
@@ -773,7 +878,7 @@ class WCS20GetCoverageMultipartTestCase(MultipartTestCase):
             node.text = "2011-01-01T00:00:00Z"
         self.xmlData = etree.tostring(tree, encoding="ISO-8859-1")
         
-        super(WCS20GetCoverageMultipartTestCase, self).testBinaryComparisonXML()
+        super(WCS20GetCoverageMultipartTestCase, self).testXMLComparison()
 
 class WCS20GetCoverageRectifiedGridCoverageMultipartTestCase(
     WCS20GetCoverageMultipartTestCase, 
@@ -809,7 +914,7 @@ class RasdamanTestCaseMixIn(object):
 # WMS test classes
 #===============================================================================
 
-class WMS11GetMapMixIn(object):
+class WMS11GetMapTestCase(RasterTestCase):
     layers = []
     styles = []
     crs = "epsg:4326"
@@ -847,10 +952,7 @@ class WMS11GetMapMixIn(object):
         else:
             return (params, "kvp", self.httpHeaders)
 
-class WMS11GetMapTestCase(WMS11GetMapMixIn, RasterTestCase):
-    pass
-
-class WMS13GetMapMixIn(object):
+class WMS13GetMapTestCase(RasterTestCase):
     layers = []
     styles = []
     crs = "epsg:4326"
@@ -893,12 +995,6 @@ class WMS13GetMapMixIn(object):
         else:
             return (params, "kvp", self.httpHeaders)
 
-class WMS13GetMapTestCase(WMS13GetMapMixIn, RasterTestCase):
-    pass
-
-class WMS13GetMapTransactionTestCase(WMS13GetMapMixIn, RasterTransactionTestCase):
-    pass
-
 class WMS13ExceptionTestCase(ExceptionTestCase):
     def getExceptionCodeLocation(self):
         return "/{http://www.opengis.net/ogc}ServiceException/@code"
